# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["WhatsappReactionParam"]


class WhatsappReactionParam(TypedDict, total=False):
    emoji: str

    message_id: str
